@@ -309,6 +309,8 @@ gdict_window_lookup_end_cb (GdictContext *context,
   gchar *message;
   gint count;
   GtkTreeIter iter;
+  GdictSource *source;
+  GdictContext *speller_context;
 
   count = window->current_definition;
 
@@ -328,6 +330,20 @@ gdict_window_lookup_end_cb (GdictContext *context,
   if (window->progress)
     gtk_widget_hide (window->progress);
 
+  /* we clone the context, so that the signals that it
+   * fires do not get caught by the signal handlers we
+   * use for getting the definitions.
+   */
+  source = gdict_source_loader_get_source (window->loader, window->source_name);
+  speller_context = gdict_source_get_context (source);
+  gdict_speller_set_context (GDICT_SPELLER (window->speller), speller_context);
+  g_object_unref (speller_context);
+  g_object_unref (source);
+
+  /* search for similar words */
+  gdict_speller_set_strategy (GDICT_SPELLER (window->speller), window->strategy);
+  gdict_speller_match (GDICT_SPELLER (window->speller), window->word);
+
   gtk_list_store_append (window->completion_model, &iter);
   gtk_list_store_set (window->completion_model, &iter,
 		      COMPLETION_TEXT_COLUMN, window->word,
@@ -421,6 +437,16 @@ get_context_from_loader (GdictWindow *window)
 
   source = gdict_source_loader_get_source (window->loader,
 		  			   window->source_name);
+  if (!source &&
+      strcmp (window->source_name, GDICT_DEFAULT_SOURCE_NAME) != 0)
+    {
+      g_free (window->source_name);
+      window->source_name = g_strdup (GDICT_DEFAULT_SOURCE_NAME);
+
+      source = gdict_source_loader_get_source (window->loader,
+                                               window->source_name);
+    }
+  
   if (!source)
     {
       gchar *detail;
@@ -1327,8 +1353,7 @@ static void
 sidebar_closed_cb (GdictSidebar *sidebar,
 		   GdictWindow  *window)
 {
-  gtk_widget_hide (window->sidebar_frame);
-  window->sidebar_visible = FALSE;
+  gdict_window_set_sidebar_visible (window, FALSE); 
 }
 
 static void
